@@ -62,9 +62,9 @@ class ServerProtocol(asyncio.Protocol):
         super().connection_lost(error)
 
 
-class EchoServer:
+class MasterServer:
     """
-    启动EchoServer服务.
+    启动MasterServer服务.
     """
 
     def __init__(self, path: str, ins=None, **kwargs) -> None:
@@ -96,5 +96,5 @@ class EchoServer:
         asyncio.run(self.task())
 
 
-m = EchoServer("../unix_sock.sock")
-m.run()
+# m = MasterServer("../unix_sock.sock")
+# m.run()
